@@ -14,10 +14,9 @@
 #'   \item [squintAngleEstimate()]
 #' }
 #'
-#' @name spinebil
-#' @docType package
-#'
-NULL
+#' @keywords internal
+"_PACKAGE"
+
 
 if(getRversion() >= "2.15.1")  utils::globalVariables(c("."))
 globalVariables(c("alpha",
